==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>AutoSave</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>Habilitar guardado automático</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>Intervalo de guardado automático:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <source>Autosave Directory:</source>
        <translation type="obsolete">Directorio:</translation>
    </message>
    <message>
        <source>auto</source>
        <translation type="obsolete">auto</translation>
    </message>
    <message>
        <location filename="../AutoSave.js" line="+34"/>
        <source>Load/Save</source>
        <translation>Cargar/Guardar</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Autosave</source>
        <translation>Guardado automático</translation>
    </message>
    <message>
        <location line="+115"/>
        <source>Autosave failed:</source>
        <translation>Guardado automático fallado:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Guardado automático se ha completado.</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation>Un archivo de copia de &apos;guardado automática&apos; para un dibujo sin título fue encontrado.
¿Quiere recuperarlo?</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation>%1 archivos de copia de &apos;guardado automática&apos; para dibujos sin título se encontraron.
¿Quiere recuperarlos?</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Recovered</source>
        <translation>Recuperado</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Recuperar archivo?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>Un archivo de copia de &apos;guardado automática&apos; para &apos;%1&apos; fue encontrado.
¿Quiere recuperarlo?</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>No se puede renombrar el archivo:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>Renombrado archivo de seguridad automática:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>Movido archivo original a:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>No se puede eliminar el archivo:</translation>
    </message>
    <message>
        <source>Cannot remove file: </source>
        <translation type="obsolete">No se puede eliminar el archivo: </translation>
    </message>
    <message>
        <source>Cannot rename backup file: </source>
        <translation type="obsolete">No se puede renombrar el archivo de copia de seguridad: </translation>
    </message>
    <message>
        <source>Moved autosave backup file to: </source>
        <translation type="obsolete">Renombrado archivo de seguridad automática:</translation>
    </message>
    <message>
        <location line="-124"/>
        <source>Recover Files?</source>
        <translation>Recuperar archivos?</translation>
    </message>
    <message>
        <source>Choose Autosave Directory</source>
        <translation type="obsolete">Elija el directorio de guardado automático</translation>
    </message>
    <message>
        <location line="-57"/>
        <source>Autosaving to:</source>
        <translation>Guardado automático de:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>AutoSave</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>Habilitar guardado automático</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>Intervalo de guardado automático:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <source>Autosave Directory:</source>
        <translation type="obsolete">Directorio:</translation>
    </message>
    <message>
        <source>auto</source>
        <translation type="obsolete">auto</translation>
    </message>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">Cargar/Guardar</translation>
    </message>
    <message>
        <location filename="../AutoSave.js" line="+35"/>
        <source>Autosave</source>
        <translation>Guardado automático</translation>
    </message>
    <message>
        <source>Open/Save</source>
        <translation type="vanished">Cargar/Guardar</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Fichero</translation>
    </message>
    <message>
        <location line="+115"/>
        <source>Autosave failed:</source>
        <translation>Guardado automático fallado:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Guardado automático se ha completado.</translation>
    </message>
    <message>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation type="vanished">Un archivo de copia de &apos;guardado automática&apos; para un dibujo sin título fue encontrado.
¿Quiere recuperarlo?</translation>
    </message>
    <message>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation type="vanished">%1 archivos de copia de &apos;guardado automática&apos; para dibujos sin título se encontraron.
¿Quiere recuperarlos?</translation>
    </message>
    <message numerus="yes">
        <location line="+19"/>
        <source>%n &apos;autosave&apos; backup file(s) for (an) untitled drawing(s) was/were found.
Do you wish to recover it/them?</source>
        <translation>
            <numerusform>Un archivo de copia de &apos;guardado automática&apos; para un dibujo sin título fue encontrado.
¿Quiere recuperarlo?</numerusform>
            <numerusform>%n archivos de copia de &apos;guardado automática&apos; para dibujos sin título se encontraron.
¿Quiere recuperarlos?</numerusform>
        </translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Recovered</source>
        <translation>Recuperado</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Recuperar archivo?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>Un archivo de copia de &apos;guardado automática&apos; para &apos;%1&apos; fue encontrado.
¿Quiere recuperarlo?</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>No se puede renombrar el archivo:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>Renombrado archivo de seguridad automática:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>Movido archivo original a:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>No se puede eliminar el archivo:</translation>
    </message>
    <message>
        <source>Cannot remove file: </source>
        <translation type="obsolete">No se puede eliminar el archivo: </translation>
    </message>
    <message>
        <source>Cannot rename backup file: </source>
        <translation type="obsolete">No se puede renombrar el archivo de copia de seguridad: </translation>
    </message>
    <message>
        <source>Moved autosave backup file to: </source>
        <translation type="obsolete">Renombrado archivo de seguridad automática:</translation>
    </message>
    <message>
        <location line="-124"/>
        <source>Recover Files?</source>
        <translation>Recuperar archivos?</translation>
    </message>
    <message>
        <source>Choose Autosave Directory</source>
        <translation type="obsolete">Elija el directorio de guardado automático</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Autosaving to:</source>
        <translation>Guardado automático de:</translation>
    </message>
</context>
</TS>
